@@ -4,16 +4,15 @@ import subprocess
 import tarfile
 from dataclasses import dataclass
 from enum import Enum
-
+from functools import cached_property
 from glob import glob
 from operator import attrgetter
-
-from graphlib import TopologicalSorter
 from pathlib import Path
 from typing import Dict, Literal, Optional, Union, List, Iterable
 
 import orjson
 import toml
+from graphlib import TopologicalSorter
 from loguru import logger
 
 from pbt.config import PBTConfig
@@ -21,11 +20,6 @@ from pbt.diff import diff_db, Diff
 from pbt.poetry import Poetry
 from pbt.version import parse_version
 
-try:
-    from functools import cached_property
-except ImportError:
-    from cached_property import cached_property
-
 
 class PackageType(str, Enum):
     Poetry = "poetry"
